# -*- perl -*-

package Bundle::HTML::Mason;

$VERSION = '0.09';

1;

__END__

=head1 NAME

Bundle::HTML::Mason - A bundle to install the HTML::Mason package

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::HTML::Mason'>

=head1 CONTENTS

Cache::Cache  1.00

Class::Container  0.07

CGI  2.46

Exception::Class  1.15

File::Spec  0.8

Params::Validate  0.70

Scalar::Util  1.01

HTML::Mason

=head1 DESCRIPTION

This bundle includes all that's needed to run the HTML::Mason package.

=cut
